##
##  m4.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2021 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         m4
Summary:      Macro Processing Language
URL:          http://www.gnu.org/software/m4/
Vendor:       Rene Seindal et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        MacroProcessor
License:      GPL
Version:      1.4.19
Release:      20210529

#   list of sources
Source0:      http://ftp.gnu.org/gnu/m4/m4-%{version}.tar.gz
Patch0:       m4.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    GNU m4 is an implementation of the traditional UNIX macro processor.
    It is mostly SVR4 compatible, although it has some extensions (for
    example, handling more than 9 positional parameters to macros).
    m4 also has builtin functions for including files, running shell
    commands, doing arithmetic, etc.

%track
    prog m4 = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/m4/
        regex     = m4-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --libdir=%{l_prefix}/lib/m4 \
        --datarootdir=%{l_prefix}

    #   build package
    %{l_make} %{l_mflags}

%install
    #   install package
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT

    #   provide alternative GNU names
    ln  $RPM_BUILD_ROOT%{l_prefix}/bin/m4 \
        $RPM_BUILD_ROOT%{l_prefix}/bin/gm4
    ln  $RPM_BUILD_ROOT%{l_prefix}/man/man1/m4.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/gm4.1

    #   strip down installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/locale
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/m4/charset.alias
    rmdir $RPM_BUILD_ROOT%{l_prefix}/lib/m4 >/dev/null 2>&1 || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

